# Dataset Documentation for Real-time OpenSim via IMUs for Full Body Kinematics

## Overview
This document provides detailed information on the dataset titled "Real-time OpenSim via IMUs for Full Body Kinematics]". It includes data dictionaries, data structure documentation, and instructions on how to utilize the dataset.

## Contents
- [Dataset Description](#dataset-description)
- [Data Dictionary](#data-dictionary)
- [Data Structure](#data-structure)

## Dataset Description
We provide a comprehensive dataset that includes optical and inertial measurements from 22 subjects engaged in a diverse set of 9 activities: walking, running, squatting, boxing, yoga, dance, badminton, stair climbing, and seated extremity exercises. The dataset also features ground truth kinematics, offline predicted kinematics, online predicted kinematics, and IMU-simulated offline predicted kinematics.

## Data Dictionary
A data dictionary provides detailed information about the variables/columns in the dataset. For each variable, include the following details:
- **Variable Name**: The name of the variable.
- **Data Type**: The type of data (e.g., integer, float, string).
- **Description**: A brief description of what the variable represents.
- **Units**: The units of measurement (if applicable).
- **Possible Values/Range**: The range of possible values or categories.

### Example Data Dictionary
| Variable Name | Data Type | Description                                           | Units      | Possible Values       |
|---------------|-----------|-------------------------------------------------------|------------|-----------------------|
| Subject       | String    | Subject ID                                            | N/A        | s001, s002, s003, ... |
| Activity      | String    | Type of activity performed                            | N/A        | walk, run, yoga, ...  |
| Time          | Float     | Time index                                            | s          | 0, 0.01, 0.02, ...    |
| LFCC_X        | Float     | LFCC marker reading in the X-axis                     | mm         | 710.5297              |
| AccelX_L_FOOT | Float     | Left foot IMU accerlerometer reading in the X-axis    | m/s^2      | 1.5389                |
| GyroX_L_FOOT  | Float     | Left foot IMU gyroscope reading in the X-axis         | deg/s      | 0.1552                |
| Quat1_L_FOOT  | Float     | Left foot IMU first quaternion reading                | N/A        | 0.0318                |
| knee_angle_r  | Float     | Right knee angle                                      | deg        | 33.5146               |

## Data Structure
Explain the structure of the dataset, including the file format (e.g., CSV, JSON), the organization of data, and any hierarchical relationships.

### Example Data Structure
- **s00x**: Each folder represents a different subject.
  - **Activity**: Subfolders represent different activities (e.g., badminton).
    - **Npose**: Contains data collected during Npose.
    - **Tpose**: Contains data collected during Tpose.
    - **Trial**: Contains data collected during trial.
        - **ground_truth_ik.csv**: Contains ground truth kinematics.
        - **offline_pred_ik.csv**: Contains offline predicted kinematics.
        - **offline_sim_ik.csv**: Contains offline simulated kinematics.
        - **online_PC_pred_ik.csv**: Contains online predicted kinematics using a PC.
        - **online_hub_ik.csv**: Contains online kinematics using the SageMotion hub.
        - **imu.csv**: Contains accelerometer, gyroscope data and quaternions.
        - **marker.csv**: Contains marker position data.
